Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(187)

Unified Diff: include/v8.h

Issue 22416003: Make JSON::Parse return Local<Value> (Closed) Base URL: http://v8.googlecode.com/svn/trunk/
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8.h
===================================================================
--- include/v8.h (revision 16081)
+++ include/v8.h (working copy)
@@ -1260,13 +1260,13 @@
class V8EXPORT JSON {
public:
/**
* Tries to parse the string |json_string| and returns it as object if
* successful.
*
* \param json_string The string to parse.
* \return The corresponding object if successfully parsed.
*/
- static Local<Object> Parse(Local<String> json_string);
+ static Local<Value> Parse(Local<String> json_string);
};
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
@@ -1260,13 +1260,13 @@
public:
/**
- * Tries to parse the string |json_string| and returns it as object if
+ * Tries to parse the string |json_string| and returns it as value if
* successful.
*
@@ -1260,13 +1260,13 @@
*
* \param json_string The string to parse.
- * \return The corresponding object if successfully parsed.
+ * \return The corresponding value if successfully parsed.
*/

Powered by Google App Engine
This is Rietveld 408576698